/* EyeView.cpp
   Copyright (C) 1998 ABiSoft, Inc. (bedev@abisoft.com)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
   
#include "EyeView.h"
#include "TMy3d.h"

/*------------------------------------------------------------*/

EyeView::EyeView(BRect frame, int32 numOfEyes) : 
	BView(frame, "BeEyes", B_FOLLOW_NONE, B_WILL_DRAW | B_FRAME_EVENTS)
{
	InitFunc(numOfEyes);
}

EyeView::EyeView(BMessage *msg) : BView(msg)
{
	msg->FindInt32("eyeNum", &fEyeNum);
	InitFunc(fEyeNum);
}
EyeView::~EyeView()
{
}
void EyeView::MessageReceived(BMessage *msg)
{
	switch(msg->what) {
		case B_ABOUT_REQUESTED:
			((TMy3d *)ChildAt(0))->AboutRequested();
			break;
		default:
			break;
	}
}
status_t EyeView::Archive(BMessage *data, bool) const
{
	BView::Archive(data, false);
	data->AddInt32("eyeNum", fEyeNum);
	data->AddString("class", "EyeView");
 	data->AddString("add_on", "application/x-vnd.abisoft-BeEyes");
	return B_OK;
}
EyeView *
EyeView::Instantiate(BMessage *data)
{
	if (!validate_instantiation(data, "EyeView")) {
		return NULL;
	}
	return new EyeView(data);
}  



void EyeView::InitFunc(int32 numOfEyes)
{
	fEyeNum = numOfEyes;
	BRect a_rect(0,0,99,99);
	int32 sideL = sqrt(fEyeNum);
	if(fEyeNum == 2) {
		sideL = 2;
	}
	for(int32 i = 0; i < fEyeNum; i++) {
		TMy3d *my_view = new TMy3d(a_rect, B_FOLLOW_ALL, 100, 100);

		AddChild(my_view);
		a_rect.OffsetBy(99,0);
		if((i+1) % sideL == 0) {
			a_rect.OffsetTo(0, (i+1) / sideL * 99);
		}
		if(i == 0)
			my_view->MainView();
	}
	a_rect = Bounds();
	a_rect.left = a_rect.right - 7;
	a_rect.top = a_rect.bottom - 7;
	
	dragger = new BDragger(a_rect, this, B_FOLLOW_NONE);
	SetViewColor(0,0,0,255);
	dragger->SetLowColor(0,0,0,255);
	AddChild(dragger);
}